.. _api_dimse_primitives:

.. py:module:: pynetdicom.dimse_primitives

Service Primitives (:mod:`pynetdicom.dimse_primitives`)
========================================================

.. currentmodule:: pynetdicom.dimse_primitives


DIMSE-C Primitives
------------------

.. autosummary::
   :toctree: generated/

   C_CANCEL
   C_ECHO
   C_FIND
   C_GET
   C_MOVE
   C_STORE

DIMSE-N Primitives
------------------

.. autosummary::
   :toctree: generated/

   N_ACTION
   N_CREATE
   N_DELETE
   N_EVENT_REPORT
   N_GET
   N_SET
